@@ -54,6 +54,7 @@ class ExcelWriter(_XlsxWriter):
             hide_log=True,
             output_renderer=None,
             embed_model=True,
+            engine_kwargs=None,
             **kwargs,
     ):
 
@@ -62,7 +63,8 @@ class ExcelWriter(_XlsxWriter):
         options = kwargs.pop('workbook_options', {})
         if 'nan_inf_to_errors' not in options:
             options['nan_inf_to_errors'] = True
-        super().__init__(*args, engine=_engine, options=options, **kwargs)
+        kwargs['options'] = options
+        super().__init__(*args, engine=_engine, engine_kwargs=kwargs)
         self.book.set_size(1600, 1200)
         self.head_fmt = self.book.add_format({'bold': True, 'font_size':14})
         self.ital_fmt = self.book.add_format({'italic': True, 'font_size':12})
@@ -121,7 +123,7 @@ class ExcelWriter(_XlsxWriter):
             ps = model.parameter_summary('df')
             ps_data_index_nlevels = ps.data.index.nlevels
             if 'Constrained' in ps.data.columns:
-                ps.data['Constrained'] = ps.data['Constrained'].str.replace("<br>",",\n")
+                ps.data['Constrained'] = ps.data['Constrained'].str.replace("<br/>",",\n")
             self.add_content_tab(ps, sheetname="Parameters", heading="Parameters" )
             if 'Constrained' in ps.data.columns:
                 n = ps.data.index.nlevels + ps.data.columns.get_loc("Constrained")
@@ -233,18 +235,19 @@ class ExcelWriter(_XlsxWriter):
                 if on_error == 'raise':
                     raise
 
-        elif nesting and isinstance(model, ModelGroup) and not model.is_mnl():
+        elif nesting and isinstance(model, ModelGroup):
             for m in model:
-                try:
-                    self.add_content_tab(m.graph.__xml__(output='png'), sheetname="Nesting", heading="Nesting Tree")
-                except:
-                    if on_error == 'raise':
-                        raise
-                try:
-                    self.add_content_tab(m.graph_descrip('nodes'), sheetname="Nesting", heading="Nesting Node List")
-                except:
-                    if on_error == 'raise':
-                        raise
+                if not m.is_mnl():
+                    try:
+                        self.add_content_tab(m.graph.__xml__(output='png'), sheetname="Nesting", heading="Nesting Tree")
+                    except:
+                        if on_error == 'raise':
+                            raise
+                    try:
+                        self.add_content_tab(m.graph_descrip('nodes'), sheetname="Nesting", heading="Nesting Node List")
+                    except:
+                        if on_error == 'raise':
+                            raise
 
         if embed:
             self.add_metadata('_self_', model)
@@ -721,4 +724,4 @@ def _estimation_statistics_excel(
         return row
     except:
         logger.exception("error in _estimation_statistics_excel")
-        raise
\ No newline at end of file
+        raise
